@@ -1,14 +1,8 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
-#
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-from kivymd.uix.screen import MDScreen
-
-from kivy.uix.progressbar import ProgressBar
 from kivy.clock import Clock
+from kivy.uix.progressbar import ProgressBar
+from kivymd.uix.screen import MDScreen
 
 
 class DecentraWelcomeScreen(MDScreen):
@@ -16,7 +10,8 @@ class DecentraWelcomeScreen(MDScreen):
 
     def __init__(self, *args, **kwargs):
         super(DecentraWelcomeScreen, self).__init__(*args, **kwargs)
-        self.update_bar_trigger = Clock.schedule_interval(self.update_bar, 0.01)
+        self.update_bar_trigger = Clock.schedule_interval(
+            self.update_bar, 0.01)
 
     def update_bar(self, dt):
         if self.ids.pb.value < 100:
