@@ -12,7 +12,7 @@ from decentra_network.lib.config_system import get_config
 from decentra_network.transactions.transaction import Transaction
 
 
-def GetMyTransaction() -> list:
+def GetMyTransaction(sended=None, validated=None, turn_json=False) -> list:
     """
     Returns the transaction db.
     """
@@ -32,4 +32,23 @@ def GetMyTransaction() -> list:
                 transaction["validated"],
                 transaction["sended"],
             ])
+
+    if sended is not None:
+        the_transactions = [tx for tx in the_transactions if tx[2] == sended]
+
+    if validated is not None:
+        the_transactions = [
+            tx for tx in the_transactions if tx[1] == validated
+        ]
+
+    if turn_json:
+        the_transactions = {
+            the_transactions.index(tx): {
+                "transaction": tx[0].dump_json(),
+                "validated": tx[1],
+                "sended": tx[2],
+            }
+            for tx in the_transactions
+        }
+
     return the_transactions
