@@ -17,9 +17,12 @@ from decentra_network.transactions.my_transactions.save_my_transaction import \
 from decentra_network.transactions.transaction import Transaction
 
 
-def SavetoMyTransaction(tx: Transaction,
-                        validated: bool = False,
-                        custom_currently_list: list = None) -> list:
+def SavetoMyTransaction(
+    tx: Transaction,
+    validated: bool = False,
+    sended: bool = False,
+    custom_currently_list: list = None,
+) -> list:
     """
     Saves the transaction to the transaction db.
     Parameters:
@@ -32,7 +35,7 @@ def SavetoMyTransaction(tx: Transaction,
 
     currently_list = (GetMyTransaction() if custom_currently_list is None else
                       custom_currently_list)
-    tx_list = [tx, validated]
+    tx_list = [tx, validated, sended]
     currently_list.append(tx_list)
 
     SaveMyTransaction(currently_list)
